﻿using System.Data.OleDb;
using System.Drawing;
using System.Drawing.Drawing2D;

using DevExpress.Data;
using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid;
using DevExpress.XtraGrid.Views.Base;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 연결
        /// </summary>
        private OleDbConnection connection;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.connection = new OleDbConnection("Provider=Microsoft.Jet.OLEDB.4.0;Data Source=nwind.mdb");

            this.gridView.InitializeView
            (
                true,                           // Multi Select
                GridMultiSelectMode.CellSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,   // Draw Focus Rect Style
                true,                           // Show Indicator
                true,                           // Show Column Headers
                true,                           // Allow Column Moving
                true,                           // Allow Column Resizing
                true,                           // Allow Filter
                true,                           // Allow Sort
                false,                          // Allow Cell Merge
                EditorShowMode.Default,         // Editor Show Mode
                false                           // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridView.OptionsView.ShowFooter = true;

            this.gridControl.DataSource = Product.GetProductList(this.connection);

            GridColumnSummaryItem unitPriceSummaryItem  = new GridColumnSummaryItem();

            unitPriceSummaryItem.FieldName     = "UnitPrice";
            unitPriceSummaryItem.SummaryType   = SummaryItemType.Max;
            unitPriceSummaryItem.DisplayFormat = "최고액 : {0:c2}";

            this.gridView.Columns["UnitPrice"].Summary.Add(unitPriceSummaryItem);

            this.gridView.BestFitColumns();

            this.gridView.CustomDrawFooter += gridView_CustomDrawFooter;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 그리드 뷰 바닥글 커스텀 그리기 - gridView_CustomDrawFooter(sender, e)

        /// <summary>
        /// 그리드 뷰 바닥글 커스텀 그리기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_CustomDrawFooter(object sender, RowObjectCustomDrawEventArgs e)
        {
            Color leftColor   = Color.FromArgb(150, Color.Gold );
            Color centerColor = Color.FromArgb(100, Color.Blue );
            Color rightColor  = Color.FromArgb(100, Color.Green);

            Rectangle leftRectangle = new Rectangle
            (
                e.Bounds.X,
                e.Bounds.Y,
                e.Bounds.Width / 2,
                e.Bounds.Height
            );

            Rectangle rightRectangle = new Rectangle
            (
                e.Bounds.X + e.Bounds.Width / 2,
                e.Bounds.Y,
                e.Bounds.Width / 2,
                e.Bounds.Height
            );

            using
            (
                LinearGradientBrush leftBrush = new LinearGradientBrush
                (
                    leftRectangle,
                    leftColor,
                    centerColor,
                    LinearGradientMode.Horizontal
                ),
                rightBrush = new LinearGradientBrush
                (
                    rightRectangle,
                    centerColor,
                    rightColor, 
                    LinearGradientMode.Horizontal
                )
            )
            {
                e.Cache.FillRectangle(leftBrush , leftRectangle );
                e.Cache.FillRectangle(rightBrush, rightRectangle);
            }

            StringFormat stringFormat = new StringFormat();

            stringFormat.LineAlignment = StringAlignment.Center;
            stringFormat.Alignment     = StringAlignment.Near;
            stringFormat.Trimming      = StringTrimming.EllipsisCharacter;

            Font font = new Font("나눔고딕코딩", 12, FontStyle.Bold);

            e.Cache.DrawString(" 커스텀 바닥글", font, new SolidBrush(Color.Navy), e.Bounds, stringFormat);

            e.Handled = true;
        }

        #endregion
    }
}